scinumtools.solver package
==========================

Submodules
----------

scinumtools.solver.AtomClass module
-----------------------------------

.. automodule:: scinumtools.solver.AtomClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.solver.ExpressionClass module
-----------------------------------------

.. automodule:: scinumtools.solver.ExpressionClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.solver.OperatorClass module
---------------------------------------

.. automodule:: scinumtools.solver.OperatorClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.solver.SolverClass module
-------------------------------------

.. automodule:: scinumtools.solver.SolverClass
   :members:
   :undoc-members:
   :show-inheritance:

scinumtools.solver.TokensClass module
-------------------------------------

.. automodule:: scinumtools.solver.TokensClass
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: scinumtools.solver
   :members:
   :undoc-members:
   :show-inheritance:
